#!/bin/bash
# shellcheck disable=SC2016,SC2002

set -e

LOG_LEVEL="${LOG_LEVEL:-warning}"

if [ "${ENV}" == "localdev" ]; then
  echo "ENV == localdev"
else
  echo "########################### Configuring Filebeat ###########################"

  # Get ECS task environment variables
  if [[ -z "$ECS_TASK_NAME" ]]; then
    echo "Missing ECS_TASK_NAME that should be set in the service ECS task definition" && exit 1
  elif [[ -z "$ECS_FAMILY_NAME" ]]; then
    echo "Missing ECS_FAMILY_NAME that should be set in the service ECS task definition" && exit 1
  fi
  echo "ECS_TASK_NAME=${ECS_TASK_NAME}"     # auth_blue
  echo "ECS_FAMILY_NAME=${ECS_FAMILY_NAME}" # hub-dev-us_auth_blue
  echo "LOG_LEVEL=${LOG_LEVEL}"             # warning

  # Get instance metadata
  AWS_DEFAULT_REGION=$(curl -s http://169.254.169.254/latest/meta-data/placement/availability-zone/ | python -c "import json,sys;val=sys.stdin.read()[:-1];print(val);") || exit 1
  AWS_INSTANCE_ID=$(curl -s http://169.254.169.254/latest/meta-data/instance-id) || exit 1
  echo "AWS_DEFAULT_REGION=${AWS_DEFAULT_REGION}"   # us-east-1
  echo "AWS_INSTANCE_ID=${AWS_INSTANCE_ID}"         # i-0ed2f37b1d1b7c828

  # Get ec2 instance tags
  ENVIRONMENT=$(aws --region "$AWS_DEFAULT_REGION" ec2 describe-tags --filters "Name=resource-id,Values=$AWS_INSTANCE_ID" "Name=key,Values=env" --query Tags[0].Value --output text)
  ECS_CLUSTER_NAME=$(aws --region "$AWS_DEFAULT_REGION" ec2 describe-tags --filters "Name=resource-id,Values=$AWS_INSTANCE_ID" "Name=key,Values=aws:autoscaling:groupName" --query Tags[0].Value --output text)
  echo "AWS_ENVIRONMENT=${ENVIRONMENT}"             # dev01
  echo "ECS_CLUSTER_NAME=${ECS_CLUSTER_NAME}"       # hub-dev-us-gateway-ecs

  # Get filebeat token from SSM
  FILEBEAT_TOKEN=$(aws --region "$AWS_DEFAULT_REGION" ssm get-parameter --name "/$ENVIRONMENT/logzio_token" --with-decryption --query 'Parameter.Value' --output text)

  # Get target service Docker ID and log path
  curl --unix-socket /var/run/docker.sock http://localhost/containers/json >> docker.json
  TARGET_CONTAINER_ID=$(cat docker.json | python -c "import json,sys;print([x['Id'] for x in json.loads(sys.stdin.read()) if 'com.amazonaws.ecs.container-name' in x['Labels'] and x['Labels']['com.amazonaws.ecs.container-name'] == sys.argv[1]][0])" "${ECS_TASK_NAME}") || exit 1
  TARGET_LOG_PATH="\/tmp\/log\/${TARGET_CONTAINER_ID}\/${TARGET_CONTAINER_ID}\-json\.log"
  echo "TARGET_CONTAINER_ID=${TARGET_CONTAINER_ID}"
  echo "TARGET_LOG_PATH=${TARGET_LOG_PATH}"

  # Get filebeat sidecar service Docker ID and log path
  FILEBEAT_CONTAINER_ID=$(cat /proc/self/cgroup | head -n 1 | cut -d '/' -f4)
  FILEBEAT_LOG_PATH="\/tmp\/log\/${FILEBEAT_CONTAINER_ID}\/${FILEBEAT_CONTAINER_ID}\-json\.log"
  echo "FILEBEAT_CONTAINER_ID=${FILEBEAT_CONTAINER_ID}"
  echo "FILEBEAT_LOG_PATH=${FILEBEAT_LOG_PATH}"

  # Update the filebeat config yml
  sed -i 's/$filebeat_token/'"$FILEBEAT_TOKEN"'/g' /tmp/filebeat.yml
  sed -i 's/$log_level/'"$LOG_LEVEL"'/g' /tmp/filebeat.yml
  sed -i 's/$env/'"$ENVIRONMENT"'/g' /tmp/filebeat.yml
  sed -i 's/$task_name/'"$ECS_TASK_NAME"'/g' /tmp/filebeat.yml
  sed -i 's/$family_name/'"$ECS_FAMILY_NAME"'/g' /tmp/filebeat.yml
  sed -i 's/$group_name/'"$ECS_CLUSTER_NAME"'/g' /tmp/filebeat.yml
  sed -i 's/$target_log_path/'"$TARGET_LOG_PATH"'/g' /tmp/filebeat.yml
  sed -i 's/$filebeat_log_path/'"$FILEBEAT_LOG_PATH"'/g' /tmp/filebeat.yml

  mv /tmp/filebeat.yml /usr/share/filebeat/filebeat.yml

  echo "Done!"

  # Only start the filebeat service when not in localdev
  exec "$@"
fi
